function [dense, inst] = meanfiringdensity (c, cluster, k, varargin)

% @CORTEX/MEANFIRINGDENSITY spike density vectors from @cortex objects
%
%    D = MEANFIRINGDENSITY(COBJ,CLUSTER,KEY) returns a smoothed spike
%    density vector computed from spike CLUSTER in the @cortex object COBJ
%    for the trials and over the epoch specified in the single-key object
%    KEY.
%
%    The smoothing algorithm uses a kernel of given width (in ms) and shape. 
%    Currently implemented kernels are 'boxcar', 'gauss', and 'epsp'.
%    By default, the function uses the values stored in giucode.def.
%    One or both parameters, however, can be specified as follows:
%    MEANFIRINGDENSITY (COBJ, CLUSTER, KEY, KERNELWIDTH, KERNELTYPE)
%
%    [D,INST] = MEANFIRINGDENSITY(...) also returns the number of trial
%    epochs included in the analysis
%
% Last modified: 18 Feb 06

% 18 Feb 06: modified from cortex/density.
%            removing 'group' parameter. key in the 3rd position, kwidth
%            and ktype are optional

spmat = spikematrix (c, cluster, k);
d = meanfiringdensity (spmat, varargin{:});
inst = size (spmat, 1);