function c = changeheadvalue (c, tset, field, newv)

%@cortex/changeheadvalue
%
% changes values in any of the following header fields:
% - condition #
% - block #
% - repeat #
% - type of trial 
% - expected response
% - response code
%
% W A R N I N G !!!
% ====================================================================
% use of this function may alter the results of your data analysis!
% changes are lost when COBJ is cleared from memory, unless COBJ.SAVEd
% ====================================================================
%
% Syntax 1: COBJ.CHANGEHEADVALUE (RULE,  FIELD) = NEWVAL
% Syntax 2: COBJ.CHANGEHEADVALUE (TRSET, FIELD) = NEWVAL
% Where:
%   COBJ:   the @cortex object
%   RULE:   a single @rule to select the trials on which to apply changes
%   TRSET:  a vector explicitly containing those trial numbers
%   FIELD:  a string specifying the header field on which to apply changes 
%           (see list above, use at least the first 3 chars)
%   NEWVAL: either a single value to apply to all selected trials
%           or a vector the same length as the number of trials
%
% If you prefer to create a new, modified object while leaving alone the
% existing one, then use the following notation
%
% Syntax 3: NOBJ = CHANGEHEADVALUE (COBJ, RULE|TRSET, FIELD, NEWVAL)
%
% Last modified: 12 May 00

% 12 May 00: lock check moved to subsassgn.m

if isa (tset, 'rules')
   ts = trialset (c, tset(1));
else
   ts = tset;
end

if length (newv) ~= 1 & length (newv) ~= length (ts)
   error ('mismatch between trialset size and number of new values');
end   

switch lower(field(1:3))
case 'con'
   c.cond_no (ts) = newv;
case 'blo'
   c.block_no (ts) = newv;
case 'res'
   c.response (ts) = newv;
case 'rep'
   c.repeat_no (ts) = newv;
case 'typ'
   c.trial_type (ts) = newv;
case 'exp'
   c.exp_response (ts) = newv;
otherwise
   error ('invalid field');
end

c.changemode = 3;
disp('CHANGES WERE APPLIED TO @CORTEX OBJECT');