function [spmat, included_trials] = getspikearray (c, cluster, k)

%@cortex/private/getspikearray.m
%
% returns a spike matrix for a single key.
%
% This is a private function, only available
% to @cortex methods
%
% Last modified: 3 Aug 02

% 18 Apr 02: tiny fixes while migrating to @keys
%  1 May 02: spike_raster indexing shifted by 1,
%            to allow spikes occurring at 0ms.
%  3 Aug 02: warning and help messages
% 24 Oct 04: various fixes, including call to trialcluster.m;
%            spmat upgraded from uint8 to double

error (NOTsinglekey (k));
included_trials = [];

% first retrieve the subset of trials to be included in the analysis
yestrials = trialset (c, k);
if isempty (yestrials)
   spmat = [];
   return;
end

% preallocate this array as if all trials were to be included
spmat = zeros (length(yestrials), k.finish - k.start);
instance = 0;
cueless = [];
winless = [];

% for each trial in the current cortex object
for trial=yestrials
   codes = c.codes (trial,:);
   times = c.times (trial,:);
   % retrieve spike time stamps for the current trial
   spikes = trialcluster (c, cluster, trial);
   % initialize the current trial's spike raster...
   last_time_stamp = max (times);
   spike_raster = zeros (1, last_time_stamp + 1);
   % ...and fill it with spikes
   spike_raster (spikes + 1) = 1; % shift by 1 to allow spikes at 0ms
   % of all requested cues, find those that are actually present
   % in the current trial. THIS MAY BE SLOW!
   cues_found = intersect (k.cues, codes);
   % warn user if no cue event is found
   if isempty (cues_found), cueless = [cueless trial]; end
   % for each cue event found
   for j=cues_found
      % there may be more than one instance of the same cue event!
      cue_event_indices = find (codes==j);
      % for each occurrence of the same cue event...
      for w = times(cue_event_indices)
         start_time = w + k.start;
         end_time   = w + k.finish-1;
         if (start_time < 1) | (end_time > last_time_stamp)
            winless = [winless trial];
         else
            instance = instance + 1;
            included_trials = [included_trials; trial];
            spmat (instance, :) = spike_raster (start_time+1:end_time+1);
         end
      end
   end
end
spmat = spmat (1:instance, :);

if ~isempty (cueless)
   warning ('could not retrieve all requested trials;');
   disp ('no cue events found in the following trial(s):');
   disp (cueless);
end
if ~isempty (winless)
   warning ('could not retrieve all requested trials;');
   disp ('time window exceeds boundaries of the following trial(s)');
   disp (winless);
end
