function c = loadump (source_filename)

% Last modified: 10 Nov 04

%========================================
%  1 May 02: last unnoted changes
% 11 Dec 02: temporarily revert to ver.2
%  7 Nov 04: version 3: epp, tch, lfp support
% 10 Nov 04: small bugfix

global GiuCoDefaultValues

f = openfile (source_filename, 'r');
temp = fread (f, 1, 'int16');
if temp==26
   erm = sprintf (...
      ['%s could be a raw cortex data file;\n'...
      'try cortex(filename,clusters) to create this object'],...
      source_filename);
   error (erm);
end
frewind (f);
% from ver. 1 on, version number is written at the beginning
% of the dump file, following the '@@@' identifying string
temp = char (fread (f, 3, 'char'))';
if strcmp (temp, '@@@')
   c.version = fread (f,  1, 'uint16');
   tn = char (fread (f, 30, 'char'))';
   c.name    = deblank (tn);
else
   % older dump files do not have the version number
   c.version = 0;
   tn = char (fread (f, 27, 'char'))';
   c.name    = [temp deblank(tn)];
end

t                   = fread (f, 1,     'uint16');
c.trials            = t;
c.cond_no           = fread (f, t,     'uint16');
c.repeat_no         = fread (f, t,     'uint16');
c.block_no          = fread (f, t,     'uint16');
c.eog_rate          = fread (f, t,     'uint8' );
c.KHz_resolution    = fread (f, t,     'uint8' );
c.trial_type        = fread (f, t,      'int16');
c.exp_response      = fread (f, t,      'int16');
c.response          = fread (f, t,     'uint16');
m                   = fread (f, 1,     'uint16');
c.times             = fread (f, [t,m], 'uint32');
c.codes             = fread (f, [t,m],  'int16');
u                   = fread (f, 1,     'uint16'); % the number of different clusters in this file
c.cluster_bank      = fread (f, [1, u],'uint16'); % the list of cluster codes
c.spike_start       = fread (f, [t,u], 'uint32' );
c.spike_end         = fread (f, [t,u], 'uint32' );
last_spike  = max (max (c.spike_end));

% this is necessary in case the file contains no spikes
if isempty (last_spike), last_spike = 0; end

% all the time stamps for all the clusters
c.spikes = uint32 (fread (f, last_spike, 'uint32' ));

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% from here on, version-dependent stuff
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%
% version 1 and up
if c.version > 0
   c.changemode = fread (f, 1, 'uint8' );
   c.rel_trial  = fread (f, t, 'uint16');
else
   c.changemode = 0;
   c.rel_trial  = 1:c.trials;
end

%%%%%%%%%%%%%%%%%%
% version 2 and up
if c.version > 1
   c.eog.dva = fread (f, 1, 'float32');
else
   c.eog.dva = 0;
end

% if eog2dva ~= 0 then read in EyePos data
if c.eog.dva
   c.eog.start      = fread (f, t, 'uint32');
   c.eog.ptr_start  = fread (f, t, 'uint32');
   c.eog.ptr_end    = fread (f, t, 'uint32');
   le = max (c.eog.ptr_end);
   c.eog.X    = int16(fread (f, le, 'int16'));
   c.eog.Y    = int16(fread (f, le, 'int16'));
end

%%%%%%%%%%%%%%%%%%
% version 3 and up
c.spike_channel = [];
c.lfp           = [];
c.epp.rate      =  0;
c.tch.rate      =  0;

if c.version > 2
   c.spike_channel = fread (f, [1, u], 'uint16');
   if fread (f, 1, 'uint8')
      c.lfp.start     = fread (f, t, 'uint32');
      c.lfp.ptr_start = fread (f, t, 'uint32');
      c.lfp_ptr_end   = fread (f, t, 'uint32');
      c.lfp_channel   = fread (f, t, 'uint32');
      ll = max (c.lfp.ptr_end);
      c.lfp.X   = int16(fread (f, ll, 'int16'));
   end
   
   c.epp.rate = fread (f, 1, 'uint16');
   if c.epp.rate
      c.epp.start = fread (f, t,   'uint32');
      c.epp.ptr   = fread (f, t+1, 'uint32');
      tl = c.epp.ptr(end);
      c.epp.ch1   = fread (f, tl, 'int16');
      c.epp.ch2   = fread (f, tl, 'int16');
   end

   c.tch.rate = fread (f, 1, 'uint16');
   if c.tch.rate
      c.tch.ptr = fread (f, t+1, 'uint32');
      tl = c.tch.ptr(end);
      c.tch.X   = fread (f, tl, 'int16');
      c.tch.Y   = fread (f, tl, 'int16');
      c.tch.T   = fread (f, tl, 'uint32');
   end
end
fclose (f);
disp (['File ''', source_filename, ''', preprocessed from ''', c.name, ''', loaded and ready.']);
return % to main
