function [spmat, included_trials] = spikematrix (c, cluster, k, group);

%@CORTEX/SPIKEMATRIX  matrix of spikes from a @cortex object
%
% [SPMAT,TRIALS] = SPIKEMATRIX(COBJ,CLUSTER,KEY);
%
% where
% COBJ:    the @cortex object;
% CLUSTER: the spike number, as encoded in the CORTEX data file;
%          if this is a vector, all spikes will be merged together;
% KEY:     a single key from a @key object; 
% SPMAT:   a matrix of 1s (a spike occurred) and 0s (no spike);
%          if you do [Y,X]=size(SPMAT) you get:
%          Y: number of spike vectors, i.e., of time windows in COBJ
%             that satisfy all criteria in the key. Note that for each
%             trial multiple and even overlapping time windows will be
%             included by the algorhythm if more than one cue event is
%             requested by the key, and/or if a cue event is present
%             more than once in the trial;
%          X: length of time window in ms;
% TRIALS:  an array containing the trial index of each analyzed epoch
%
% Last modified: 27 Oct 04

% 22 Dec 98: last relevant changes
% 12 May 00: small fixes
%  8 Apr 02: migrating to 'newcortex'
% 10 Oct 02: end of @newcortex testing phase
%  1 Nov 02: tiny help msg fixes
% 24 Oct 04: include getspikearray2 call (for 'short' trials);
%            help text revised
% 27 Oct 04: cosmetics

global GiuCoDefaultValues
if isempty (GiuCoDefaultValues), readefs; end

error (NOTsinglekey(k));
ks = k.size;

switch nargin
   case 3
      switch class (k)
         case 'key'
            k1 = 1;    % current key
            k2 = 1:ks; % subkeys
         case 'rules'
            k1 = 1; % current group
            k2 = 1; % current rule
         otherwise
            error ('wrong parameter type');
      end
   case 4
      k1 = group;       % group
      k2 = 1:ks(group); % rules in group
   otherwise
      error ('wrong number of arguments');
end

spmat = [];
index  = [];
for sk = k2
	if GiuCoDefaultValues.spikes.include_short_trials
      [a, it] = getspikearray2 (c, cluster(1), k(k1, sk));
   else
      [a, it] = getspikearray (c, cluster(1), k(k1, sk));
   end
   % do this only if different clusters should be merged together
   for i=2:prod(size(cluster))
      if GiuCoDefaultValues.spikes.include_short_trials
         moresp = getspikearray2 (c, cluster(i), k(k1, sk));
      else
         moresp = getspikearray (c, cluster(i), k(k1, sk));
      end
      a = or (a, moresp);
   end
   spmat = [spmat; a];
   index = [index; it];
end
[included_trials, i] = sort (index);
% this sorts the spike matrix by trial number
spmat = spmat (i, :);
