function frates = trialfiringrate (c, cluster, binsize, r, group)

%@CORTEX/TRIALFIRINGRATE  trial-by-trial firing rates from a @cortex object
%
% TRIALFIRINGRATE(CO,CLUSTER,KEY)  returns an array of spike/second
%    rates, one for each of the trial epochs selected by KEY, a single
%    key from a @key object, for unit CLUSTER of the CO @cortex
%    object, computed over the epoch specified by the key. Note that
%    any NaNs in the spike matrix will be treated as missing values.
%
% TRIALFIRINGRATE(CO,CLUSTER,BINSIZE,KEY)  the analysis epoch as
%    specified by the key is subdivided into BINSIZE-ms bins; firing
%    rates are computed for each of the bins and returned as an M-by-N
%    matrix, where M is the number of successfully analyzed epochs and
%    N is the number of bins.
%
% Last modified: 10 Nov 04

% since 17 Apr 00...
% 14 Jul 00: help text fixes
% 11 Nov 02: overloaded function
% 17 Apr 03: call to truncspm
%  1 May 04: help text fixes
% 27 Oct 04: allow NaNs in spikematrix
% 10 Nov 04: help text

switch nargin
   case 5
      spmat = spikematrix (c, cluster, r, group);
   case 4
      spmat = spikematrix (c, cluster, r);
   case 3
      spmat = spikematrix (c, cluster, binsize);
      binsize = size (spmat, 2);
   otherwise
      error ('wrong number of arguments');
end

% fix and get info on spmat
[spmat, instances, winsize, numofbins] = truncspm (spmat, binsize);

% compute the firing rates
s1 = reshape(spmat, instances, binsize, numofbins);
s2 = permute (s1, [2 1 3]);
s3 = nanmean (s2) * 1000;
frates  = squeeze (s3);