function sp = addcombo (sp, label, keys)

%@SPIX/ADDCOMBO defines and stores a combination of keys in a @spix
%
%   Analyses run using a key COMBO as a restriction combine together
%   trials selected by all keys in the combo, and return only one
%   result. On the other hand,  analyses restricted to a GROUP of keys
%   return distinct values for each key in the group (see ADDGROUP).
%   
%   SP = ADDCOMBO(SP,LABEL,KEYS) stores in SP the key combo specified
%   in KEYS. KEYS can be a key label, a set of key labels (in a cell
%   array of strings), one of 'none' 'all' 'first' 'last', or a
%   numeric array specifying the ordinal numbers of the keys that will
%   be part of the combo; the string LABEL is the name of the combo.
%
%   SP = ADDCOMBO(SP,LABEL) a combo named LABEL is created with all
%   currently selected keys
%
%   Note that if LABEL already exists as a combo name, the new combo
%   will replace the existing one
%
%Modified: 26 Nov 04

%  9 Aug 03, by Giuseppe Bertini, based on addgroup
% 26 Nov 04: help text

if nargin > 2
   ks = parsegrouping (sp.k, keys);
   if isempty(ks), error ('none of the requested keys exists'); end
   disp ([num2str(length(ks)) ' keys']);
else
   disp ('all the currently "included" keys')
   ks = sp.inkeys;
end

sset = lbl2idx (sp.combos, label);
if sset
   disp ('redefining an existing combo');
else
   disp ('creating a new combo');
   sset = sp.ncombos + 1;
   sp.combos(sset).label = label;
   sp.ncombos = sset;
end

sp.combos(sset).keys = ks;