function as = addata (as, data, levels)

%@ANNSETUP/ADDATA   adds observations to an @annsetup object
%
%   AS = ADDATA(AS,DATA,LEVELS) adds to AS the set of observations
%   contained in the numeric vector DATA; LEVELS specifies the levels
%   associated to the data (one level per factor, obviously). LEVELS can be
%   a numeric vector, a cell array, or a character matrix (one row per
%   level).
%
%   For example:
%   >> as=annsetup(3); % object creation for a 3-way anova
%   >> d=[6 5 7 6 8 7 5 7 6]; % the data associated with...
%   >> g={'blue',1,'up'};     % ...the three factor levels
%   >> as=addata(as,d,g);
%   >> ...
%
%   Note that the object variable must appear both as the first input
%   argument and as the output.
%
%Last modified: 2 Aug 03

% handle data
error (NOTnumvector (data));
as.D = [as.D; vvector(data)];

% handle levels
if isnumeric (levels)
	error (NOTisnumvector(levels));
	levels = num2cell (levels);
elseif ~iscell(levels)
	error ('LEVELS must be either a numeric vector or a cell array');
end
if length (levels) ~= as.N
   error  (['wrong number of levels: this is a ' num2str(as.N) '-factor @annsetup object']);
end

for ii = 1:as.N
	lev = levels{ii};
	ln = length (as.L{ii});
	if ischar(lev)
		m = strmatch (lev, as.L{ii});
		if isempty (m)
			warning (['adding new level "' lev '" to factor "' as.F{ii} '"']);
			m = ln+1;
			as.L{ii}{m} = lev;
		end
	else
		if lev>ln
			warning (['adding level ' num2str(lev) ' to factor']);
			m = ln+1;
			as.L{ii}{m} = sprintf ('level%02d', m);
		else
			m = lev
		end
	end
   rr = repmat (m, length(data), 1);
   tt = as.G{ii};
   as.G {ii} = [tt; rr];
end
if as.verbose
    info (as)
end
