function as = facts (factors, levels)

%@FACTS/FACTS
%
%   rewrite this!
%
%   the @facts object class provides a handy way to
%   prepare data for input into Matlab Stats Toolbox's ANOVAN function.
%   ANOVAN performs n-way anovas and requires properly formatted data and
%   grouping matrices. If your raw data is available in vectors of
%   observations associated with known levels for each of the factors, then
%   @facts will save you a few lines of clunky code.
%
%   Constructor's syntax: AS = FACTS(N)
%   creates and returns a @facts object.
%   N can be either the number of factors in the analysis to be performed,
%   or a cell array containing the names of each factor (recommended).
%
%Last modified: 31 Jan 06

% Last unnoted changes: 02 AUg 03
% 03 Aug 05: factor labeling added to constructor syntax
% 31 Jan 06: verbosity added

as.D = [];
if isnumscalar (factors)
   as.N = factors;
	for i=1:as.N
		as.F{i} = sprintf ('factor%02d', i);
	end
elseif iscell (factors)
   as.N = length(factors);
   as.F = factors;
else
   error ('wrong argument type');
end

if nargin > 1
	if ~iscell (levels), error ('LEVELS must be a cell array'); end
	if length (levels) ~= as.N
		error ('LEVELS must have as many cells as there are factors');
	end
	as.L = levels;
else
	as.L = repmat ({[]}, as.N, 1);
end

as.G = repmat ({[]}, as.N, 1);
as.verbose = false;
as = class (as, 'facts');

disp ([num2str(as.N) '-way analysis with factors:']);
disp (as.F');
disp ('successfully set up.');