function [rocarea, rocfa, rochit] = amdroc(signal, noise)
% function [rocarea, rocfa, rochit ] = roc(signal noise) calculates roc area, roc false alarms
% and roc hits. Rocfalse alarms and rochits are vectors to allow plotting
% of an ROC curve.
% Input arguments are signal and noise vectors which are assumed to be
% vectors of integer spike counts. The lengths of the signal and noise vectors can be
% different.

%empty matrices
rocfa = [];
rochit = [];
if(min(size(signal)) >1)
    error('Signal must be a vector');
end
if(min(size(noise)) >1)
    error('Noise must be a vector');
end
nsignal = length(signal);
nnoise = length(noise);
rocindex = 1;
rocfa(rocindex) = 0;
rochit(rocindex) = 0;
firstcrit = max([max(signal) max(noise)]);
lastcrit =min([min(signal) min(noise)]);
for criterion = firstcrit:-1:lastcrit-1
    hits = length(find(signal > criterion));
    fa = length(find(noise > criterion));
    if((hits ~= rochit(rocindex)) || (fa ~= rocfa(rocindex)))
        if((rocindex ==1)) %if this move is in the same direction as last move we can overwrite it
            rocindex = rocindex + 1;
        elseif((hits ~= rochit(rocindex-1)) && (fa ~= rocfa(rocindex-1))) %if this move is in the same direction as last move we can overwrite it
            rocindex = rocindex + 1;
        end
        rochit(rocindex) = hits;
        rocfa(rocindex) = fa;
    end
end
rochit = rochit/nsignal;
rocfa = rocfa/nnoise;
% if (rochit(rocindex) < 1) || (rocfa(rocindex) < 1)
%     rocindex = rocindex+1;
%     rocfa(rocindex) = 1;
%     rochit(rocindex) = 1;
% end
rocarea = 0;
for index = 1:rocindex -1;
    index2 = index+1;
    rocarea = rocarea + (rochit(index) + rochit(index2)) * (rocfa(index2) - rocfa(index))/2;
end
