function h = barerr (b, L, U, varargin)

% BARERR  adds error bars to existing bar charts
%
%   BARERR(B,E) draws error bars on the B barseries; the height of the
%   error bars is E; E must be as long as there are bars on the chart.
%
%   BARERR(B,L,U) lower and upper error bar heights are specified separately
%
%   BARERR(...,LineSpec) draws the error bars using specifications
%   described in >> doc linespec
%
%   H = BARERR(...) returns handles to the errorbarseries objects created.
%
% Last modified: 07 Mar 06


switch nargin
	case {0 1}
		error ('not enough arguments');
	case 2
		U=L;
	otherwise
		if isstring (U)
			varargin = [U varargin];
			U=L;
		end
end
            
noho = ~ishold; hold on

[xc yc] = midofbars (b);
xc  = vvector (xc);
yc  = vvector (yc);
Ler = vvector (L);
Uer = vvector (U);
t  = errorbar (xc, yc, Ler, Uer, 'linestyle', 'none', 'color', 'black', varargin{:});
if noho, hold off; end
if nargout, h=t; end