function dense = smooth (raw, kwidth, ktype)
%SMOOTH  smoothed data; core code for 'density' plots.
%        Originally borrowed from Wael
%
%Last modified: 17 Feb 06

% Since 06 Nov 04:
% 17 Feb 06: function turned into generic smoothing procedure;
%            requires a vector instead of a spmat.

raw = horzarray (raw);
error (NOTstring (ktype,  'KERNELTYPE' ));
error (NOTscalar (kwidth, 'KERNELWIDTH'));
% make sure the kwidth is of even size
kwidth = kwidth - rem (kwidth, 2);
halfwin = kwidth/2;
spl = length (raw);
if  spl <= halfwin
	dense=[];
	s = sprintf ('input Vector must be longer than half of the kernel width.\nReturning the empty matrix...');
	warning (s);
	return;
end;

switch lower(ktype)
case 'gauss'
   x = -halfwin:halfwin;
   kernel = exp (-x.^2/halfwin^2);
case 'boxcar'
   kernel = ones (kwidth + 1, 1);
case 'epsp'
   t=0:kwidth;
   tg=1;
   td=20;
   r = (1-exp (-t/tg)).*(exp(-t/td));
   kernel = r /sum(r);
otherwise
   error ('type should be one of ''gauss'', ''boxcar'', ''epsp''');
end
kernel = kernel / sum (kernel);
padded = zeros (1, spl + kwidth * 2);
padded (halfwin + 1 : spl + halfwin) = raw;
padded (1:halfwin) = ...
	repmat (mean (raw (1:halfwin)), 1, halfwin);
padded (halfwin + spl + 1 : spl + kwidth) = ...
	repmat (mean (raw(spl-halfwin:spl)), 1, halfwin);
dense = filter (kernel, 1, padded);
dense = dense (kwidth+1 : end-kwidth);
